@@ -7,9 +7,9 @@ The files are located in the data directory.
 from pathlib import Path
 
 TEST_PATH = Path(__file__).parents[0]  # directory of test files
-DATA_PATH = TEST_PATH / "data"  # directory of data for tests
+DATA_DIR = TEST_PATH / "data"  # directory of data for tests
 
-MODEL_PATH = DATA_PATH / "models"
+MODEL_PATH = DATA_DIR / "models"
 MODEL_REPRESSILATOR = MODEL_PATH / "repressilator.xml"
 MODEL_GLCWB = MODEL_PATH / "body21_livertoy_flat.xml"
 MODEL_DEMO = MODEL_PATH / "Koenig_demo_14.xml"
